import Vue from 'vue';
import { ApolloError, ApolloOperationContext, GraphQLError, InputValidationError, ProcessedApolloError, ServerError, UnauthorizedError } from './types';
export declare function isApolloError(error: ApolloError | any): error is ApolloError;
export declare function isGraphQLError(error: GraphQLError | any): error is GraphQLError;
export declare class ApolloErrorProcessor<TApp = Vue, TContext = ApolloOperationContext> {
    static FriendlyMessages: Record<string, string>;
    processedErrors: ProcessedApolloError[];
    protected readonly originalError: Error;
    protected readonly app: TApp;
    protected readonly context: TContext;
    constructor(error: ApolloError, app: TApp, context: TContext);
    showErrorNotifications(): void;
    cleanError(error: ApolloError | GraphQLError | Record<string, any>): Error;
    protected isUnauthorizedError(error: GraphQLError): boolean;
    protected onUnauthorizedError(error: UnauthorizedError): void;
    protected onServerError(error: ServerError): void;
    protected onInputValidationError(error: InputValidationError): void;
    protected getFriendlyMessage(errorCode: string, errorMessage: string): string;
    protected getFriendlyMessage(errorCode: string): string | undefined;
    protected processErrorMessage(message: GraphQLError['message']): string;
    protected normalizeError(error: GraphQLError | Error): Error;
    private processApolloError;
    private processGraphQLError;
    private processNetworkError;
}
